@@ -1,10 +1,12 @@
 function populateOffsets(columns) {
     let rows = Math.ceil(fileLen / columns);
-    let container = document.getElementById('offsets');
+    let elements = "";
     var offset = 0;
 
     for (var i = 0; i < rows; ++i) {
-        container.innerHTML += offset.toString(16) + "</br>\n";
+        elements += offset.toString(16) + "</br>\n";
         offset += columns;
     }
+
+    document.getElementById('offsets').innerHTML = elements;
 }
