@@ -147,7 +147,7 @@ fn generate_help(o: &mut String) {
 
     w!(o, 4, "<p>Legend</p>");
     w!(o, 4, "<ul>");
-    for (class, desc) in legend_items {
+    for (class, desc) in &legend_items {
         w!(o, 5, "<li><span class='legend_rect {}'></span>{}</li>", class, desc);
     }
     w!(o, 4, "</ul>");
@@ -459,8 +459,6 @@ fn add_offsets_script(o: &mut String, elf: &ParsedElf) {
 
     wnonl!(o, 0, "{}", include_str!("js/offsets.js").indent_lines(3));
 
-    w!(o, 3, "populateOffsets({})", DEFAULT_COLUMNS);
-
     w!(o, 2, "</script>");
 }
 
@@ -480,6 +478,8 @@ fn add_arrows_script(o: &mut String, elf: &ParsedElf) {
         w!(o, 3, "connect('#bin_shdr{} > .sh_offset', '#bin_section{}');", i, i);
     }
 
+    w!(o, 3, "pushArrowElems();");
+
     w!(o, 2, "</script>");
 }
 
@@ -669,13 +669,17 @@ fn generate_body(o: &mut String, elf: &ParsedElf) {
 
     generate_file_info_table(o, elf);
 
-    w!(o, 2, "<div id='offsets'></div>");
+    w!(o, 2, "<div id='offsets'>");
+    for off in (0..elf.contents.len()).step_by(DEFAULT_COLUMNS) {
+        w!(o, 3, "{:x}</br>", off);
+    }
+    w!(o, 2, "</div>");
 
-    w!(o, 2, "<div id='bytes'>");
+    wnonl!(o, 2, "<div id='bytes'>");
     wnonl!(o, 0, "{}", generate_file_dump(elf));
     w!(o, 2, "</div>");
 
-    w!(o, 2, "<div id='ascii'>");
+    wnonl!(o, 2, "<div id='ascii'>");
     generate_ascii_dump(o, elf);
     w!(o, 2, "</div>");
 
